@@ -8,16 +8,16 @@ nms <- nms[order(as.numeric(substring(nms,6)))] # warning <== "MW.nm2.old"
 
 set.seed(123)
 for(n in nms) {
-    obj <- get(n, pos = ppos)
-    cat("\n",n,":\n"); print(obj)
+    o <- get(n, pos = ppos)
+    cat("\n",n,":\n"); print(o)
     cat("4 random X from", n,":")
-    print(rnorMix(4, obj))
-}
+    print(rnorMix(4, o))
 
-## Testing of sort.norMix():
-stopifnot(sapply(nms, function(n) {
-    o <- get(n)
+    ## Testing of sort.norMix():
     if(is.unsorted(o[,"mu"]))
         o <- sort(o)
-    identical(o, sort(o))
-}))
+    ae <- all.equal(o, sort(o), tolerance = 4e-16) # non-stable sorting, MW.
+    if(!isTRUE(ae)) {
+        cat("sort(o) differs from o:\n"); print(ae)
+    }
+}
